==> aroundme_0_6_2.zip: aroundme_0_6_2/aroundme/language/1/barnraiser_01/sn_list.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'sn_common.lang.php');

//section titles
$lang['hdr_statistics'] = 					"in summary";
$lang['hdr_social_network'] = 				"your social network";
$lang['hdr_im_pending'] = 						"outstanding invitations";


//ERRORS
$lang['err_no_pending_requests'] = 				"You have no outstanding invitations. Why not <a href=\"sn_invite.php\">invite your friends</a>.";
$lang['err_no_people'] = 						"Sorry, nobody is listed.";


//TXT
$lang['txt_social_network'] = 					"social networking";
$lang['txt_social_network_intro'] = 			"Your world revolves around you and your network. Your network is your most vital communications asset. Use it!<br /><p>Social networking is built upon the idea of degrees of relationship to you, so you are the centre of your network and thus you are degree zero. Your friends are one degree away and their friends are two degrees away from you and so on.<br /></p>";
$lang['txt_outstanding_invites'] = 				"outstanding invites";
$lang['txt_outstanding_invites_intro'] = 		"people you have invited to join you and who have not yet joined";
$lang['txt_your_social_network'] = 				"your social network";
$lang['txt_your_social_network_intro'] = 		"all the people in your network";
$lang['txt_total_online_users'] = 				"total users online";
$lang['txt_total_users'] = 						"total users";
$lang['txt_view_all_network'] = 				"view all";
$lang['txt_network'] = 							"network"; // breadcrumbBLOCKED
$lang['txt_blocked'] = 							"BLOCKED";

?>

==> aroundme_0_6_8.zip: aroundme_0_6_8/aroundme/language/1/barnraiser_01/sn_list.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

//section titles
$lang['hdr_statistics'] = 						"in summary";
$lang['hdr_social_network'] = 					"social network";
$lang['hdr_directory'] = 						"directory";
$lang['hdr_im_pending'] = 						"outstanding invitations";


//ERRORS
$lang['err_no_pending_requests'] = 				"You have no outstanding invitations. Why not <a href=\"sn_invite.php\">invite your friends</a>.";
$lang['err_no_people'] = 						"Sorry, nobody is listed.";


//TXT
$lang['txt_social_network'] = 					"social networking";
$lang['txt_social_network_intro'] = 			"Your world revolves around you and your network. Your network is your most vital communications asset. Use it!<br /><p>Social networking is built upon the idea of degrees of relationship to you, so you are the centre of your network and thus you are degree zero. Your friends are one degree away and their friends are two degrees away from you and so on.<br /></p>";
$lang['txt_outstanding_invites'] = 				"outstanding invites";
$lang['txt_outstanding_invites_intro'] = 		"people you have invited to join you and who have not yet joined";
$lang['txt_your_social_network'] = 				"your social network";
$lang['txt_your_social_network_intro'] = 		"all the people in your network";
$lang['txt_total_online_users'] = 				"total users online";
$lang['txt_total_users'] = 						"total users";
$lang['txt_view_all_network'] = 				"view all";
$lang['txt_blocked'] = 							"BLOCKED";


// BREADCRUMB (texts that appears when you role over the breadcrumb navigation)
$lang['nav_breadcrumb'] = 						"network";

?>
